clear all

**** The following directory structure must be setup to run the code ****

global Path "./AristodemouRosen_2022_QE"
global P "$Path/Application"

**** Set path to data source *****
**** /home/*USERNAME*/Desktop/Network/data ****
global DataPath "/home/eleni_a/Desktop/Network/data"

log using "$Path/Application/Estimation_Data_Creation_Aristodemou and Rosen (2022).log",replace

***************************************************************************************************************************************************

*DATA USED: Kantar FMCG Purchase Panel Data 

***************************************************************************************************************************************************

***************************************************************************************************************************************************

*PURCHASE DATA: Razor Blades (RF509) for the years 2004-2005

***************************************************************************************************************************************************

use "$DataPath/TNS/extractedfiles/purchase_data/Derived_data_by_rfy/RF509_2004.dta"
append using "$DataPath/TNS/extractedfiles/purchase_data/Derived_data_by_rfy/RF509_2005.dta"

*Rename year as demyear to match the labelling in the hh_panel.dta later on (year of purchase)
rename year demyear
rename size productsize

***************************************************************************************************************************************************
 
*PRODUCT ATTRIBUTES

***************************************************************************************************************************************************
sort prodcode
merge m:1 prodcode using "$DataPath/TNS/extractedfiles/product_attributes/WAVES/2008-2012/rf509_0812.dta",force 
keep if _merge==3
drop _merge

*Keep only Women's razor blades
keep if razorsector=="Womens Razor"

*************************************************************************************************************************************************** 

*HOUSEHOLD CHARACTERISTICS

***************************************************************************************************************************************************
sort hhno demyear
merge m:1 hhno demyear using "$DataPath/TNS/extractedfiles/panel_data/hhpanel_all.dta",force
keep if _merge==3
drop _merge

*Keep only female main shopper
drop if mssex==2

*************************************************************************************************************************************************** 

*STORE DATA

***************************************************************************************************************************************************

sort shopid shopcode
merge m:1 shopid shopcode using  "$DataPath/TNS/extractedfiles/store_data/storecode10.dta",force
drop if _merge==2
codebook shopid if _merge==1
drop _merge

*Fill in  shop information for those stores not matched with the storecode10 using storecode.dta

*Save the name of the store from the storecode10 data as fascia10
rename fascia fascia10
sort shopid
merge m:1 shopid using "$DataPath/TNS/extractedfiles/store_data/storecode.dta",force
drop if _merge==2 
replace fascia10=fascia if fascia10==""
drop fascia
rename fascia10 fascia
drop _merge

***************************************************************************************************************************************************

*Full Data statistics

*************************************************************************************************************************************************** 

*Original data sample size
sum hhno
*Female main shopper
tab mssex
*Year of purchase
tab demyear

*Women's razors only
tab razorsector

*Report sectors in data: Table 7 in PAPER
tab reportsector

*************************************************************************************************************************************************** 

*Remove observations not used

*************************************************************************************************************************************************** 

*Delete the observations who bought system blades with razor
drop if reportsector=="Bought With Razor"

*Drop observations with system blades from other brands other than Gillete or Wilkinson Sword
drop if rangetradingcompany=="Boots Other" & reportsector=="System Blades"
drop if rangetradingcompany=="Sainsbury" & reportsector=="System Blades"
drop if rangetradingcompany=="Superdrug" & reportsector=="System Blades"
drop if rangetradingcompany=="Tesco" & reportsector=="System Blades"
drop if rangetradingcompany=="Personna" & reportsector=="System Blades"

*////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// 

*************************************************************************************************************************************************** 

*HOUSEHOLD DATA CREATION*
 
*************************************************************************************************************************************************** 

*Keep only Female main shopper between the ages of 18-50 
tab mssex
*Keep only individuals between the ages 18-50
keep if msage>17&msage<51
tab msage

*************************************************************************************************************************************************** 
*Employment Status of main shopper
*************************************************************************************************************************************************** 

tab msempstat
*Grouping together unemployed with not working
replace msempstat=4 if msempstat==12
*Drop the unkown employment status 
drop if msempstat==0 
*Drop the retired individuals
drop if msempstat==6

*Table 9 in PAPER
tab msempstat

*EMPLOYMENT STATUS IN PAPER: Table 3 in PAPER

gen EMPLOYMENT=(msempstat==1|msempstat==2|msempstat==3)
tab EMPLOYMENT

*************************************************************************************************************************************************** 
*Age of main shopper
*************************************************************************************************************************************************** 

*AGE GROUPS IN PAPER: AGE_18_30 AGE_31_40 AGE_41_50
gen AGE_18_30=(msage<31)
gen AGE_31_40=(msage>30 & msage<41)
gen AGE_41_50=(msage>40 & msage<51)

*Table 3 in PAPER
tab AGE_18_30
tab AGE_31_40
tab AGE_41_50

*************************************************************************************************************************************************** 
*Marital status of main shopper
*************************************************************************************************************************************************** 

*Table 9 in PAPER
tab msmarstat

*Merging the category Single with Divorced/Widowed/Sepated into category Other in paper

*MARITAL STATUS IN PAPER: Table 3 in PAPER

gen MARRIED=(msmarstat==1)
tab MARRIED

*************************************************************************************************************************************************** 
*Number of females in the household
*************************************************************************************************************************************************** 

*First row corresponds to "One female" in Table 9
tab nfemales

*NUMBER OF FEMALES IN THE PAPER: Table 3 in PAPER

gen MORE_FEMALES=(nfemales>1)
tab MORE_FEMALES

***************************************************************************************************************************************************
*Total sample size for application
***************************************************************************************************************************************************

sum hhno

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

*************************************************************************************************************************************************** 

*PRODUCT DATA CREATION

*************************************************************************************************************************************************** 

***************************************************************************************************************************************************
*Blades and Blade types
***************************************************************************************************************************************************
gen razor_bladetype=rangetradingcompany if reportsector=="System Blades"
replace razor_bladetype="Disposable Razors" if reportsector=="Disposables"

gen blade=1 if bladetype=="Single Blade"
replace blade=2 if bladetype=="Double Blade"
replace blade=3 if bladetype=="Triple Blade"
replace blade=4 if bladetype=="Quattro Blade"

*Table 1 in PAPER
tab razor_bladetype

***************************************************************************************************************************************************
*System Blades: Brand and Blade combination statistics
***************************************************************************************************************************************************
gen brand_blade="G2" if rangetradingcompany=="Gillette" & blade==2 & reportsector=="System Blades"
replace brand_blade="G3" if rangetradingcompany=="Gillette" & blade==3 & reportsector=="System Blades"
replace brand_blade="W2" if rangetradingcompany=="Wilkinson Sword" & blade==2 & reportsector=="System Blades"
replace brand_blade="W3" if rangetradingcompany=="Wilkinson Sword" & blade==3 & reportsector=="System Blades"

*Table 2 in PAPER
tab rangetradingcompany if reportsector=="System Blades"
tab blade if reportsector=="System Blades"
tab brand_blade if reportsector=="System Blades"

*************************************************************************************************************************************************** 
*Pack size specification
*************************************************************************************************************************************************** 

*Packsize=Number of cardridges in each pack, volume=total volume purchased, npacks=number of packs purchased
gen packsize=volume/npacks
tab packsize

*Table 10 in PAPER
tab packsize if rangetradingcompany=="Gillette" & reportsector=="System Blades"
tab packsize if rangetradingcompany=="Wilkinson Sword" & reportsector=="System Blades"
tab packsize if  blade==2 & reportsector=="System Blades"
tab packsize if  blade==3 & reportsector=="System Blades"
tab packsize if reportsector=="Disposables"

*PACK SIZE IN PAPER
gen pack_size="S" if packsize<5
replace pack_size="M" if packsize>4 & packsize<8
replace pack_size="L" if packsize>7

*Table 11 in PAPER
tab pack_size if reportsector=="System Blades"
tab pack_size

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

*STORE DATA CREATION*

***************************************************************************************************************************************************

***************************************************************************************************************************************************
*Correct for missing store names using information on shop codes "shopcode" and group stores
***************************************************************************************************************************************************

*Missing fascias: 40 observations were missing and will be matched using the shopcode
tab shopcode if fascia==""

*SAFEWAY
tab fascia if shopcode==480
replace fascia="SAFEWAY" if shopcode==480
*16 missing observations with shopcode 480 were replaced with fascia SAFEWAY

*ASDA: 
tab fascia if shopcode==790
tab fascia if shopcode==791
replace fascia="ASDA" if shopcode==790
replace fascia= "ASDA" if shopcode==791
*group all ASDA stores and replace 2 missing values with shopcode 790

*SAVACENTRE
tab fascia if shopcode==771
tab shopcode if fascia=="SAVACENTRE"
replace fascia="SAVACENTRE" if shopcode==771
*replace 1 missing observation with shopcode 771
 
*SOMERFIELD
tab fascia if shopcode==711
replace fascia="SOMERFIELD" if shopcode==711
*group all SOMERFIELDS and replace 2 missing fascias with shopcode 711

*KWIKSAVE
tab fascia if shopcode==941
replace fascia="KWIKSAVE" if shopcode==941
*group all KWIKSAVEs and replace 1 missing fascia with shopcode 941

*DEFAULT
tab shopcode if fascia=="DEFAULT"
tab fascia if shopcode==200
tab fascia if shopcode==709
tab fascia if shopcode==747
tab fascia if shopcode==749
tab fascia if shopcode==754
tab fascia if shopcode==786
tab fascia if shopcode==907

*MORRISONS
tab fascia if shopcode==170
replace fascia="MORRISONS" if shopcode==170
*group all MORRISONS

*SUPERDRUG
tab fascia if shopcode==690
replace fascia="SUPERDRUG" if shopcode==690
*replace 6 missing observations with shopcode 690 with fascia SUPERDRUG

*WAITROSE
tab fascia if shopcode==720
replace fascia="WAITROSE" if shopcode==720
*group all WAITROSEs

*CO-OP
tab fascia if shopcode==615
* replace 1 missing observation with shopcode 615 with fascia CO-OP
replace fascia="CO-OP" if shopcode==615
replace fascia="CO-OP" if fascia=="CO-OP FOOD STORE"
replace fascia="CO-OP" if fascia=="CO-OP OTHER"
replace fascia="CO-OP" if fascia=="CO-OP SUPERMARKET"
replace fascia="CO-OP" if fascia=="CO-OP LATE SHOP"
replace fascia="CO-OP" if fascia=="CO-OP OTHER (CENTRAL MIDS)"
replace fascia="CO-OP" if fascia=="CO-OP OTHER (SCOT MID)"
replace fascia="CO-OP" if fascia=="CO-OP OTHER(FIVEWAYS)"
replace fascia="CO-OP" if fascia=="CO-OP PIONEER"
replace fascia="CO-OP" if fascia=="CO OP OTHER"
replace fascia="CO-OP" if fascia=="COOP OTHER"
replace fascia="CO-OP" if fascia=="CO OP OTHER (EX ALLDAYS)"
*group all CO-OPs

*SAINSBURY's
tab fascia if shopcode==770
replace fascia="SAINSBURY" if fascia=="" & shopcode==770
*replace 2 missing fascias with shopcode=770
replace fascia="SAINSBURY" if fascia=="SAINSBURY (H/DLVRY)"
replace fascia="SAINSBURY" if fascia=="SAINSBURY (SAFEWAY)"
replace fascia="SAINSBURY" if fascia=="SAINSBURY CENTRAL"
replace fascia="SAINSBURY" if fascia=="SAINSBURY (SAVACENTRE)"
*group all SAINSBURY's

*TESCO
tab fascia if shopcode==780
replace fascia="TESCO" if shopcode==780
*group all fascias with shopcode=780 and replace 6 missing observations with shopcode 780 with fascia TESCO
tab fascia if shopcode==782
replace fascia="TESCO" if shopcode==782
*group all fascias with shopcode 782 and replace 3 missing observations with shopcode 782 with fascia TESCO
tab fascia if shopcode==786
replace fascia="TESCO" if shopcode==786
*46 observations from the fascia DEFAULT had shopcode 786 and these were merged with the TESCO observations

*Group remaining TESCOs
replace fascia="TESCO" if fascia=="TESCO METRO"
replace fascia="TESCO" if fascia=="TESCO EXPRESS"
*group all TESCOs

*ALLOTHER:Group together all the fascias with name starting with "OTHER" and that have 6 or less observations 
replace fascia="ALLOTHER" if fascia=="OTHER CHEMIST"
replace fascia="ALLOTHER" if fascia=="OTHER DEPT. STORES"
replace fascia="ALLOTHER" if fascia=="OTHER DISC. DRUGSTORE"
replace fascia="ALLOTHER" if fascia=="OTHER"
replace fascia="ALLOTHER" if fascia=="OTHER GROCER/CORNERSTORE"
replace fascia="ALLOTHER" if fascia=="ALDI"
replace fascia="ALLOTHER" if fascia=="BUDGEN"
replace fascia="ALLOTHER" if fascia=="CASH & CARRY"
replace fascia="ALLOTHER" if fascia=="LLOYDS"
replace fascia="ALLOTHER" if fascia=="NETTO"
replace fascia="ALLOTHER" if fascia=="POUNDSTRETCHER"
replace fascia="ALLOTHER" if fascia=="WOOLWORTH"

*Table 12 in PAPER
tab fascia

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

*MONTH DATA CREATION*

***************************************************************************************************************************************************

rename month month_original
gen month=ym(demyear,month_original)
format %tm month
tab month

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

*COMPUTE AVERAGE PRICES*

***************************************************************************************************************************************************

***************************************************************************************************************************************************
*Average unit price per cartridge: Equation 6.1 in the PAPER. 
*This is the sum of expenditure divided by the sum of the volume for a specific brand-quality combination (rangetradingcompany-blade)  sold in a specific pack size (pack_size), per reportsector (Disposables or System Blades) and per month and store (fascia).
***************************************************************************************************************************************************

bys reportsector rangetradingcompany blade month fascia  pack_size: egen total_expenditure=sum(expenditure)
bys reportsector rangetradingcompany blade month fascia  pack_size: egen total_volume=sum(volume)
gen average_price=total_expenditure/total_volume

***************************************************************************************************************************************************
*Average prices for double and trile blade razors for System Blades in Appendix B
***************************************************************************************************************************************************

sum average_price if blade==2 & reportsector=="System Blades"
sum average_price if blade==3 & reportsector=="System Blades"

***************************************************************************************************************************************************
*Table 8 in PAPER
***************************************************************************************************************************************************
sum average_price if rangetradingcompany=="Gillette" & blade==2 & reportsector=="System Blades"
sum average_price if rangetradingcompany=="Gillette" & blade==3 & reportsector=="System Blades"
sum average_price if rangetradingcompany=="Wilkinson Sword" & blade==2 & reportsector=="System Blades"
sum average_price if rangetradingcompany=="Wilkinson Sword" & blade==3 & reportsector=="System Blades"

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

*PRODUCT NAMES FOR SYSTEM BLADES in Appendix B in PAPER*

***************************************************************************************************************************************************
tab brand if rangetradingcompany=="Gillette" & blade==2 & reportsector=="System Blades"
tab brand if rangetradingcompany=="Gillette" & blade==3 & reportsector=="System Blades"
tab brand if rangetradingcompany=="Wilkinson Sword" & blade==2 & reportsector=="System Blades"
tab brand if rangetradingcompany=="Wilkinson Sword" & blade==3 & reportsector=="System Blades"

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

*DATA CREATION FOR COUNTERFACTUAL PRICES ESTIMATION*

***************************************************************************************************************************************************

***************************************************************************************************************************************************
* Delete blade and rangetradingcompany for Disposables as these won't be used
***************************************************************************************************************************************************

replace blade=. if reportsector=="Disposables"
replace rangetradingcompany="" if reportsector=="Disposables"

***************************************************************************************************************************************************
*Create dummies for pack_size=M and pack_size=L
***************************************************************************************************************************************************

gen sizeM=(pack_size=="M")
gen sizeL=(pack_size=="L")

***************************************************************************************************************************************************
*Create dummy for triple blade for system blades alone
***************************************************************************************************************************************************

gen TripleBlade=(blade==3) if reportsector=="System Blades"

***************************************************************************************************************************************************
*Create dummy for Wilkinson Sword for system blades alone
***************************************************************************************************************************************************

gen WilkinsonSword=(rangetradingcompany=="Wilkinson Sword") if reportsector=="System Blades"

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

save "$P/Clean_Data.dta",replace

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

*COUNTERFACTUAL PRICES ESTIMATION*

***************************************************************************************************************************************************

***************************************************************************************************************************************************

*EQUATION(6.2) CONDITIONAL ON PACK SIZE

***************************************************************************************************************************************************

use "$P/Clean_Data.dta", clear

***************************************************************************************************************************************************
*Equation 6.2 in the PAPER for system blades alone: Table 13
***************************************************************************************************************************************************
xi: reg average_price i.month i.fascia WilkinsonSword TripleBlade sizeM sizeL if  reportsector=="System Blades"

***************************************************************************************************************************************************
*Counterfactual prices as predicted from regression above 
***************************************************************************************************************************************************

*PRICE_G2
replace TripleBlade=0
replace WilkinsonSword=0
predict price_G2
*PRICE_G3
replace TripleBlade=1
replace WilkinsonSword=0
predict price_G3
*PRICE_W2
replace TripleBlade=0
replace WilkinsonSword=1
predict price_W2
*PRICE_W3
replace TripleBlade=1
replace WilkinsonSword=1
predict price_W3

***************************************************************************************************************************************************
*Replace the predicted prices with the "observed prices" if the specific brand-quality combination was chosen
***************************************************************************************************************************************************

replace price_G2= average_price if rangetradingcompany=="Gillette" & blade==2 & reportsector=="System Blades"
replace price_G3= average_price if rangetradingcompany=="Gillette" & blade==3 & reportsector=="System Blades"
replace price_W2= average_price if rangetradingcompany=="Wilkinson Sword" & blade==2 & reportsector=="System Blades"
replace price_W3= average_price if rangetradingcompany=="Wilkinson Sword" & blade==3 & reportsector=="System Blades"

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

* PREPARING ESTIMATION DATA USING EQ(6.2) FOR R-CODE*

***************************************************************************************************************************************************

gen B=0
replace B=1 if rangetradingcompany=="Gillette" & reportsector=="System Blades"
replace B=2 if rangetradingcompany=="Wilkinson Sword" & reportsector=="System Blades"
gen Y=0
replace Y=1 if blade==2 & reportsector=="System Blades"
replace Y=2 if blade==3 & reportsector=="System Blades"

*Replacing B=1 for Y=0 for code in R: Y=0 denotes outside alternative. B is meaningless-setting B=1 by convention
replace B=1 if Y==0

keep Y B AGE_31_40 AGE_41_50 EMPLOYMENT MARRIED MORE_FEMALES  price_G2 price_G3 price_W2 price_W3 
order price_G2 price_G3 price_W2 price_W3 B Y AGE_31_40 AGE_41_50 EMPLOYMENT MARRIED MORE_FEMALES
sort price_G2 price_G3 price_W2 price_W3 B Y AGE_31_40 AGE_41_50 EMPLOYMENT MARRIED MORE_FEMALES   

***************************************************************************************************************************************************
*Estimation Data Table 4
***************************************************************************************************************************************************
save "$P/Estimation_Data_Table4_Aristodemou_and_Rosen(2022).dta",replace

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

*ALTERNATIVE SPECIFIC CONDITIONAL LOGIT MODEL ESTIMATION* 

***************************************************************************************************************************************************

***************************************************************************************************************************************************
*PREPARE DATA FOR ASCLOGIT ESTIMATION
***************************************************************************************************************************************************

***************************************************************************************************************************************************
*Setting Prices for Disposables to zero
***************************************************************************************************************************************************

gen price_00=0

***************************************************************************************************************************************************
*Create product purchased variable
***************************************************************************************************************************************************

gen product=0
replace product=11 if B==1 & Y==1
replace product=12 if B==1 & Y==2
replace product=21 if B==2 & Y==1
replace product=22 if B==2 & Y==2

***************************************************************************************************************************************************
*Reshape data for asclogit estimation
***************************************************************************************************************************************************

rename price_00 price0
rename price_G2 price11
rename price_G3 price12
rename price_W2 price21
rename price_W3 price22

gen N=_n
reshape long price, i(N) j(BY 0 11 12 21 22)

***************************************************************************************************************************************************
*Create choice variable indicating product purchased
***************************************************************************************************************************************************

gen choice=0
replace choice=1 if BY==product

***************************************************************************************************************************************************
*Create high-quality (blade 3) and brand (Wilkinson Sword) dummies for asclogit estimation
***************************************************************************************************************************************************

gen quality=0
replace quality=1 if BY==12
replace quality=1 if BY==22

gen wilkinson=0
replace wilkinson=1 if BY==21
replace wilkinson=1 if BY==22

***************************************************************************************************************************************************
*Alternative specific logit model: Table 14 in PAPER
***************************************************************************************************************************************************

asclogit choice price quality wilkinson, case(N) alternatives(BY) casevars(AGE_31_40 AGE_41_50 MARRIED EMPLOYMENT  MORE_FEMALES) basealternative(0) noconstant

***************************************************************************************************************************************************
*Own and Cross price elasticities estimation 
***************************************************************************************************************************************************

*Predicted probabilites
predict p, pr
*Own-price elasticities
gen ownelasticities=_b[price]*(1-p)*price 
*Cross-price elasticities
gen crosselasticities=-_b[price]*p*price 

***************************************************************************************************************************************************
*Mean and Quantile estimation: Table 15 in PAPER
***************************************************************************************************************************************************

*Disposables ownelasticities
sum ownelasticities if BY==0
centile ownelasticities if BY==0, centile(20 50 80)

*G2 ownelasticities
sum ownelasticities if BY==11
centile ownelasticities if BY==11, centile(20 50 80)

*G3 ownelasticities
sum ownelasticities if BY==12
centile ownelasticities if BY==12, centile(20 50 80)

*W2 ownelasticities
sum ownelasticities if BY==21
centile ownelasticities if BY==21, centile(20 50 80)

*W3 ownelasticities
sum ownelasticities if BY==22
centile ownelasticities if BY==22, centile(20 50 80)

*Disposables crosselasticities
sum crosselasticities if BY==0
centile crosselasticities if BY==0, centile(20 50 80)

*G2 crosselasticities
sum crosselasticities if BY==11
centile crosselasticities if BY==11, centile(20 50 80)

*G3 crosselasticities
sum crosselasticities if BY==12
centile crosselasticities if BY==12, centile(20 50 80)

*W2 crosselasticities
sum crosselasticities if BY==21
centile crosselasticities if BY==21, centile(20 50 80)

*W3 crosselasticities
sum crosselasticities if BY==22
centile crosselasticities if BY==22, centile(20 50 80)

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

*EQUATION (6.3) UNCONDITIONAL ON PACK SIZE

***************************************************************************************************************************************************

use "$P/Clean_Data.dta", clear

***************************************************************************************************************************************************
*Equation 6.3 in the PAPER for system blades alone: Table 13
***************************************************************************************************************************************************
xi: reg average_price i.month i.fascia WilkinsonSword TripleBlade if  reportsector=="System Blades"

***************************************************************************************************************************************************
*Counterfactual prices as predicted from regression above 
***************************************************************************************************************************************************

*PRICE_G2
replace TripleBlade=0
replace WilkinsonSword=0
predict price_G2
*PRICE_G3
replace TripleBlade=1
replace WilkinsonSword=0
predict price_G3
*PRICE_W2
replace TripleBlade=0
replace WilkinsonSword=1
predict price_W2
*PRICE_W3
replace TripleBlade=1
replace WilkinsonSword=1
predict price_W3

***************************************************************************************************************************************************
*Replace the predicted prices with the "observed prices" if the specific brand-quality combination was chosen
***************************************************************************************************************************************************

replace price_G2= average_price if rangetradingcompany=="Gillette" & blade==2 & reportsector=="System Blades"
replace price_G3= average_price if rangetradingcompany=="Gillette" & blade==3 & reportsector=="System Blades"
replace price_W2= average_price if rangetradingcompany=="Wilkinson Sword" & blade==2 & reportsector=="System Blades"
replace price_W3= average_price if rangetradingcompany=="Wilkinson Sword" & blade==3 & reportsector=="System Blades"

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************************************************************************************************************************************************

* PREPARING ESTIMATION DATA USING EQ(6.3) FOR R-CODE*

***************************************************************************************************************************************************

gen B=0
replace B=1 if rangetradingcompany=="Gillette" & reportsector=="System Blades"
replace B=2 if rangetradingcompany=="Wilkinson Sword" & reportsector=="System Blades"
gen Y=0
replace Y=1 if blade==2 & reportsector=="System Blades"
replace Y=2 if blade==3 & reportsector=="System Blades"

*Replacing B=1 for Y=0 for code in R: Y=0 denotes outside alternative. B is meaningless-setting B=1 by convention
replace B=1 if Y==0

keep Y B AGE_31_40 AGE_41_50 EMPLOYMENT MARRIED MORE_FEMALES  price_G2 price_G3 price_W2 price_W3 
order price_G2 price_G3 price_W2 price_W3 B Y AGE_31_40 AGE_41_50 EMPLOYMENT MARRIED MORE_FEMALES
sort price_G2 price_G3 price_W2 price_W3 B Y AGE_31_40 AGE_41_50 EMPLOYMENT MARRIED MORE_FEMALES   

***************************************************************************************************************************************************
*Estimation Data Table 5
***************************************************************************************************************************************************
save "$P/Estimation_Data_Table5_Aristodemou_and_Rosen(2022).dta",replace

*//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

log close
 
