

############# Function Load_POR_Data_IFS_16par loads data for the partially ordered response model
# ---- Input parameters ---
# dtapath: The path of the .dta file to load
# ---- Return parameters ---
# The following are elements of a list that is returned
# B: N * 1 matrix of brand choices
# Y: N * 1 matrix of quality choices
# X1: N * k_beta1 matrix of covariates affecting brand 1 choice.
# X2: N * k_beta1 matrix of covariates affecting brand 2 choice.
#     Note that here k_beta1 and k_beta2 must be 5.
#     Note X1 and X2 could contain common components or be identical.
# P: N * 2 * 2 array of prices. P(i,b,y) is the price for combination (b,y) faced by consumer i.
#     Note that ymax from a previous implementation is no longer used. The max quality choice is fixed at 2 in the current implementation.
######################################################################################################
Load_POR_Data_IFS_16par <- function(dtapath) {
  
  # LOAD THE DATA
  PORdata <- read_dta(dtapath)
  PORdata <- as.matrix(PORdata)
  class(PORdata)<-"numeric"
  
  # SET COVARIATES
  age_31_40 <- as.integer(PORdata[,7])
  age_41_50 <- as.integer(PORdata[,8])# Leave one group out due to the constant
  married <- as.integer(PORdata[,9])
  employed <- as.integer(PORdata[,11])
  more_females<-as.integer(PORdata[,10])
  X1 <- cbind(age_31_40,age_41_50,married,more_females,employed)
  X2 <- X1

  # SET PRICES 
  P<-array(dim=c(dim(PORdata)[1],2,2))
  P[,1,1] <- PORdata[,1]
  P[,2,1] <- PORdata[,3]
  P[,1,2] <- PORdata[,2]
  P[,2,2] <- PORdata[,4]
  
  # SET CHOICES
  B<-PORdata[,5]
  Y<-PORdata[,6]
 
  return(list(B = B, Y = Y, X1 = X1, X2 = X2, P = P)) 
}