# Source this file to run Monte Carlo Experiments.

rm(list=ls())

# Set working directory
setwd("./Aristodemou_Rosen_2022_QE/Monte Carlos")

if (!require("mvtnorm")) install.packages("mvtnorm")                         
library(mvtnorm)    
if (!require("pbivnorm")) install.packages("pbivnorm")  
library(pbivnorm)
if (!require("Rsolnp")) install.packages("Rsolnp")  
library(Rsolnp)
if (!require("matrixcalc")) install.packages("matrixcalc")  
library(matrixcalc)

source("POR_Sim_Linear.R")
source("POR_Likelihood_Functions_Final.R")
source("POR_MC_Functions.R")

rseed <- 987698764
set.seed(rseed)

lower = rep(-5,16)
upper = rep(5,16)
lower[15] <- -1
upper[15] <- 1
lower[16] <- 0.001
upper[16] <- 4
stepsize <- rep(0.5,16)
stepsize[15] <- 0.01
stepsize[16] <- 0.1

gosolnp_fullML_simulations <- 500
gosolnp_profileML_simulations <- 0 # This has produced the same coverage probabilities as setting to 500 in some Monte Carlo experiments
# 500 is used in constructing confidence intervals. Here the profile search can begin from the known true parameter value, so choosing random
# start values seems unnecessary.

#theta <- c(2,1,-1.6,0,-0.1,-0.2,-0.2,0,0.1,0,-0.1,0,-0.2,0.01,0.8,1.00)

theta <- c(1.00,0.80,-1.50,-1.20,1.30,0.30,-0.10,-0.30,0.70,1.00,0.30,-0.10,-0.30,0.70,0.50,1.00)

MCparameters <- list(#SampleSizes = c(200,500,1000,2000),
                     SampleSizes = c(200),
                     R = 1000,
                     theta = theta,
                     lower = lower, upper = upper, stepsize = stepsize,
                     alpha = 0.05,
                     gosolnp_full_ML_simulations = gosolnp_fullML_simulations,
                     gosolnp_profileML_simulations = gosolnp_profileML_simulations,
                     parameter_indices = seq(1,16,1),
                     #DGPs = c(1,2,3))
                     DGPs = 3)

p.payoff.likelihood <- function(theta_sub, f_data) { # likelihood function for payoff parameters with rho and sigma fixed at the truth.
  return(neg.full.likelihood(theta = c(theta_sub,theta[15:16]), f_data = f_data))
}

# Function k.full.likelihood is a helper function for k.profile.likelihood used to profile out
# all components other than k in calls to optimizers solnp and gosolnp.
k.full.likelihood <- function(theta_minus_k_arg, f_data, theta_k_val, kpos) {
  theta_arg <- append(theta_minus_k_arg, theta_k_val, after=kpos)
  return(neg.full.likelihood(theta = theta_arg, f_data = f_data))
}

# Function k.profile.likelihood computes the profile likelihood at the given value of theta_k
# Pass in nsim = 0 to skip gosolnp
k.profile.likelihood <- function(theta_k_val, theta_minus_k_start, LB_minus_k, UB_minus_k, f_data, k, nsim) {
  if (nsim > 0) {
    gosolnp_result <- gosolnp(par = theta_minus_k_start, fun = k.full.likelihood, LB = LB_minus_k, UB = UB_minus_k,
                              control = list(trace = 0), n.sim = nsim, rseed = rseed,
                              f_data = f_data, theta_k_val = theta_k_val, kpos = (k-1))
  } else {
    gosolnp_result <- NULL
  }
  solnp_result <- solnp(par = theta_minus_k_start, fun = k.full.likelihood, LB = LB_minus_k, UB = UB_minus_k,
                        control = list(trace = 0), f_data = f_data, theta_k_val = theta_k_val, kpos = (k-1))
  if (is.null(gosolnp_result)) {
    return (solnp_result)
  } else if (gosolnp_result$values[length(gosolnp_result$values)] < solnp_result$values[length(solnp_result$values)]) {
    return(gosolnp_result)
  } else {
    return(solnp_result)
  }
}

# CALL FUNCTION TO EXECUTE FULL BATTERY OF MCS HERE
mctimes_test <- Execute_MC_Simulations(MCparameters)



